#ifndef NT2_INCLUDE_FUNCTIONS_ISREAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ISREAL_HPP_INCLUDED

#include <nt2/predicates/include/functions/isreal.hpp>

#endif
